@@ -1,5 +1,5 @@
-## ------------------------------------------------------------------------
-require(Rvmmin)
+## -----------------------------------------------------------------------------
+require(optimx)
 sq<-function(x){
    nn<-length(x)
    yy<-1:nn
